@@ -1,4 +1,3 @@
-# coding: utf-8
 """
 Some common design patterns such as singleton and cached classes.
 """
@@ -103,7 +102,7 @@ class NullFile:
         """
         Pass through
         """
-        return open(os.devnull, "w")
+        return open(os.devnull, "w")  # pylint: disable=R1732
 
     def __init__(self):
         """no-op"""
