@@ -1,4 +1,3 @@
-# coding: utf-8
 """
 Augments Python's suite of IO functions with useful transparent support for
 compressed files.
@@ -7,6 +6,7 @@ compressed files.
 import os
 import bz2
 import gzip
+import lzma
 import time
 import errno
 import mmap
@@ -18,7 +18,7 @@ from pathlib import Path
 
 def zopen(filename: Union[str, Path], *args, **kwargs) -> IO:
     r"""
-    This function wraps around the bz2, gzip and standard python's open
+    This function wraps around the bz2, gzip, lzma, xz and standard python's open
     function to deal intelligently with bzipped, gzipped or standard text
     files.
 
@@ -40,7 +40,9 @@ def zopen(filename: Union[str, Path], *args, **kwargs) -> IO:
         return bz2.open(filename, *args, **kwargs)
     if ext in (".GZ", ".Z"):
         return gzip.open(filename, *args, **kwargs)
-    return io.open(filename, *args, **kwargs)
+    if ext in (".XZ", ".LZMA"):
+        return lzma.open(filename, *args, **kwargs)
+    return open(filename, *args, **kwargs)  # pylint: disable=R1732
 
 
 def reverse_readfile(filename: Union[str, Path]) -> Generator[str, str, None]:
@@ -209,7 +211,7 @@ class FileLock:
                 if e.errno != errno.EEXIST:
                     raise
                 if (time.time() - start_time) >= self.timeout:
-                    raise FileLockException("%s: Timeout occured." % self.lockfile)
+                    raise FileLockException(f"{self.lockfile}: Timeout occured.")
                 time.sleep(self.delay)
 
         self.is_locked = True
