@@ -1,10 +1,10 @@
-# coding: utf-8
 """
 Pretty printing functions.
 """
 
 from io import StringIO
 import sys
+from json import JSONEncoder, loads
 
 
 def pprint_table(table, out=sys.stdout, rstrip=False):
@@ -17,11 +17,12 @@ def pprint_table(table, out=sys.stdout, rstrip=False):
         out: Output stream (file-like object)
         rstrip: if True, trailing withespaces are removed from the entries.
     """
+
     def max_width_col(table, col_idx):
         """
         Get the maximum width of the given column index
         """
-        return max([len(row[col_idx]) for row in table])
+        return max(len(row[col_idx]) for row in table)
 
     if rstrip:
         for row_idx, row in enumerate(table):
@@ -56,7 +57,7 @@ def draw_tree(node, child_iter=lambda n: n.children, text_str=lambda n: str(n)):
 
     Based on https://pypi.python.org/pypi/asciitree/
     """
-    return _draw_tree(node, '', child_iter, text_str)
+    return _draw_tree(node, "", child_iter, text_str)
 
 
 def _draw_tree(node, prefix, child_iter, text_str):
@@ -67,16 +68,60 @@ def _draw_tree(node, prefix, child_iter, text_str):
     # check if root node
     if prefix:
         buf.write(prefix[:-3])
-        buf.write('  +--')
+        buf.write("  +--")
     buf.write(text_str(node))
-    buf.write('\n')
+    buf.write("\n")
 
     for index, child in enumerate(children):
-        if index+1 == len(children):
-            sub_prefix = prefix + '   '
+        if index + 1 == len(children):
+            sub_prefix = prefix + "   "
         else:
-            sub_prefix = prefix + '  |'
+            sub_prefix = prefix + "  |"
 
         buf.write(_draw_tree(child, sub_prefix, child_iter, text_str))
 
     return buf.getvalue()
+
+
+class DisplayEcoder(JSONEncoder):
+    """
+    Help convert dicts and objects to a format that can be displayed in notebooks
+    """
+
+    def default(self, o):
+        """
+        Try diffent ways of converting the present object for displaying
+        """
+        try:
+            return o.as_dict()
+        except Exception:
+            pass
+
+        try:
+            return o.__dict__
+        except Exception:
+            pass
+
+        try:
+            return str(o)
+        except Exception:
+            pass
+
+        return None
+
+
+def pprint_json(data):
+    """
+    Display a tree-like object in a jupyter notebook.
+    Allows for collapsable interactive interaction with data.
+
+    Args:
+        data: a dictionary or object
+
+    Based on:
+    https://gist.github.com/jmmshn/d37d5a1be80a6da11f901675f195ca22
+
+    """
+    from IPython.display import JSON, display  # pylint: disable=C0415
+
+    display(JSON(loads(DisplayEcoder().encode(data))))
